@@ -18,9 +18,11 @@
 #' @seealso
 #' \code{surival}
 #' @examples
-#' vlist <- c("Age", "Sex", "Married", "BMI", "Education", "Income")
+#' \dontrun{
+#' vlist <- c("Age", "Sex", "BMI", "Education", "Income")
 #' results <- all_cox(crude = "Surv(t0, t1, Endpoint) ~ Diabetes", xlist = vlist, data = diab_df)
 #' results
+#' }
 #' @name all_cox
 all_cox <- function(crude, xlist, data, na_omit = TRUE, ...) {
   data <- data.frame(c(data[all.vars(as.formula(crude))], data[xlist]))
@@ -49,9 +51,9 @@ all_cox <- function(crude, xlist, data, na_omit = TRUE, ...) {
   md_lst <- lapply(comb_lst, function(x) paste(crude, "+", paste(x, collapse = "+")))
   models <- lapply(md_lst, function(x) coxph(as.formula(x), ..., data = data))
   p <- unlist(lapply(models, function(x) tidy(x)$p.value[1]))
-  estimate <- unlist(lapply(models, function(x) tidy(x, exponentiate = TRUE)$estimate[1]))
-  conf_low <- unlist(lapply(models, function(x) tidy(x, exponentiate = TRUE)$conf.low[1]))
-  conf_high <- unlist(lapply(models, function(x) tidy(x, exponentiate = TRUE)$conf.high[1]))
+  estimate <- unlist(lapply(models, function(x) tidy(x, exponentiate = TRUE, conf.int = TRUE)$estimate[1]))
+  conf_low <- unlist(lapply(models, function(x) tidy(x, exponentiate = TRUE, conf.int = TRUE)$conf.low[1]))
+  conf_high <- unlist(lapply(models, function(x) tidy(x, exponentiate = TRUE,  conf.int = TRUE)$conf.high[1]))
   n <- unlist(lapply(models, function(x) broom::glance(x)$n))
   aic <- unlist(lapply(models, function(x) stats::AIC(x)))
   df_coef <- data.frame(
